@@ -25,26 +25,23 @@ __all__ = [
     "AreaOfInterest",
 ]
 
-import warnings
 from array import array
 from itertools import chain, islice
 
 from pyproj import CRS, Proj
-from pyproj._transformer import (  # noqa
-    AreaOfInterest,
-    _Transformer,
-    transformer_list_from_crs,
-)
+from pyproj._transformer import AreaOfInterest, _Transformer, _TransformerGroup  # noqa
 from pyproj.compat import cstrencode
 from pyproj.enums import TransformDirection, WktVersion
 from pyproj.exceptions import ProjError
 from pyproj.utils import _convertback, _copytobuffer
 
 
-class TransformerGroup:
+class TransformerGroup(_TransformerGroup):
     """
     The TransformerGroup is a set of possible transformers from one CRS to another.
 
+    .. versionadded:: 2.3.0
+
     From PROJ docs::
 
         The operations are sorted with the most relevant ones first: by
@@ -86,28 +83,15 @@ class TransformerGroup:
             best operation for the area.
 
         """
-        self._transformers = []
-        self._unavailable_operations = []
-        self._best_available = True
-        for iii, operation in enumerate(
-            transformer_list_from_crs(
-                CRS.from_user_input(crs_from),
-                CRS.from_user_input(crs_to),
-                skip_equivalent=skip_equivalent,
-                always_xy=always_xy,
-                area_of_interest=area_of_interest,
-            )
-        ):
-            if isinstance(operation, _Transformer):
-                self._transformers.append(Transformer(operation))
-            else:
-                self._unavailable_operations.append(operation)
-                if iii == 0:
-                    self._best_available = False
-                    warnings.warn(
-                        "Best transformation is not available due to missing "
-                        "{!r}".format(operation.grids[0])
-                    )
+        super(TransformerGroup, self).__init__(
+            CRS.from_user_input(crs_from),
+            CRS.from_user_input(crs_to),
+            skip_equivalent=skip_equivalent,
+            always_xy=always_xy,
+            area_of_interest=area_of_interest,
+        )
+        for iii, transformer in enumerate(self._transformers):
+            self._transformers[iii] = Transformer(transformer)
 
     @property
     def transformers(self):
@@ -142,6 +126,9 @@ class Transformer:
     is to make repeated transforms faster.
 
     Additionally, it provides multiple methods for initialization.
+
+    .. versionadded:: 2.1.0
+
     """
 
     def __init__(self, base_transformer=None):
@@ -191,12 +178,41 @@ class Transformer:
     @property
     def area_of_use(self):
         """
+        .. versionadded:: 2.3.0
+
         Returns
         -------
         AreaOfUse: The area of use object with associated attributes.
         """
         return self._transformer.area_of_use
 
+    @property
+    def remarks(self):
+        """
+        .. versionadded:: 2.4.0
+
+        str: Remarks about object.
+        """
+        return self._transformer.remarks
+
+    @property
+    def scope(self):
+        """
+        .. versionadded:: 2.4.0
+
+        str: Scope of object.
+        """
+        return self._transformer.scope
+
+    @property
+    def operations(self):
+        """
+        .. versionadded:: 2.4.0
+
+        tuple[CoordinateOperation]: The operations in a concatenated operation.
+        """
+        return self._transformer.operations
+
     @staticmethod
     def from_proj(
         proj_from,
@@ -207,6 +223,10 @@ class Transformer:
     ):
         """Make a Transformer from a :obj:`~pyproj.proj.Proj` or input used to create one.
 
+        .. versionadded:: 2.1.2 skip_equivalent
+        .. versionadded:: 2.2.0 always_xy
+        .. versionadded:: 2.3.0 area_of_interest
+
         Parameters
         ----------
         proj_from: :obj:`~pyproj.proj.Proj` or input used to create one
@@ -248,6 +268,10 @@ class Transformer:
     ):
         """Make a Transformer from a :obj:`~pyproj.crs.CRS` or input used to create one.
 
+        .. versionadded:: 2.1.2 skip_equivalent
+        .. versionadded:: 2.2.0 always_xy
+        .. versionadded:: 2.3.0 area_of_interest
+
         Parameters
         ----------
         crs_from: ~pyproj.crs.CRS or input used to create one
@@ -311,6 +335,9 @@ class Transformer:
         """
         Transform points between two coordinate systems.
 
+        .. versionadded:: 2.1.1 errcheck
+        .. versionadded:: 2.2.0 direction
+
         Parameters
         ----------
         xx: scalar or array (numpy or python)
@@ -419,6 +446,8 @@ class Transformer:
         """
         Iterator/generator version of the function pyproj.Transformer.transform.
 
+        .. versionadded:: 2.1.1 errcheck
+        .. versionadded:: 2.2.0 direction
 
         Parameters
         ----------
@@ -557,6 +586,37 @@ class Transformer:
         """
         return self._transformer.to_wkt(version=version, pretty=pretty)
 
+    def to_json(self, pretty=False, indentation=2):
+        """
+        Convert the projection to a JSON string.
+
+        .. versionadded:: 2.4.0
+
+        Parameters
+        ----------
+        pretty: bool
+            If True, it will set the output to be a multiline string. Defaults to False.
+        indentation: int
+            If pretty is True, it will set the width of the indentation. Default is 2.
+
+        Returns
+        -------
+        str: The JSON string.
+        """
+        return self._transformer.to_json(pretty=pretty, indentation=indentation)
+
+    def to_json_dict(self):
+        """
+        Convert the projection to a JSON dictionary.
+
+        .. versionadded:: 2.4.0
+
+        Returns
+        -------
+        dict: The JSON dictionary.
+        """
+        return self._transformer.to_json_dict()
+
     def __str__(self):
         return self.definition
 
@@ -585,6 +645,9 @@ def transform(
     always_xy=False,
 ):
     """
+    .. versionadded:: 2.1.2 skip_equivalent
+    .. versionadded:: 2.2.0 always_xy
+
     x2, y2, z2 = transform(p1, p2, x1, y1, z1)
 
     Transform points between two coordinate systems defined by the
@@ -688,6 +751,9 @@ def itransform(
     always_xy=False,
 ):
     """
+    .. versionadded:: 2.1.2 skip_equivalent
+    .. versionadded:: 2.2.0 always_xy
+
     points2 = itransform(p1, p2, points1)
     Iterator/generator version of the function pyproj.transform.
     Transform points between two coordinate systems defined by the
